N.C. Appellate Courts
Keywords: supreme, court

COURT OF APPEALS OPINIONS - 2013
Last Modified: July 13 2014 11:27:56 PM

17 December 2013 Zip File of Published Opinions Mandate: 6 January 2014 Case Title / Description
Blair Invs., LLC v. Roanoke Rapids City Council, (13-690) — headnotes Special Use Permit
Capital Bank, N.A. v. Cameron, (13-696) — headnotes Venue; Forum Selection Clauses; Consent to Jurisdiction Clauses
Elliott v. KB Home N.C., Inc., (13-352) — headnotes Arbitration; Class Action; Waiver
In re A.F., (13-610) — headnotes End of Probation; Modification Motion; Prior History Points
Joyner v. Perquimans Cnty. Bd. of Educ., (13-446) — headnotes Career status; whole record test; arbitrary and capricious
Lloyd v. Norfolk S. Ry. Co., (13-379) — headnotes Failure to Mitigate Damages; Excessive Damages
Morgan v. Morgan Motor Co. of Albemarle, (12-1485) — headnotes Workers' Compensation; Arising out of and in the course of
Parsons v. Parsons, (13-714) — headnotes Modification of alimony and child support; Attorney's fees
Schmidt v. Petty, (13-278) — headnotes Evidence; Rule 403 analysis
Simpson v. Sears, Roebuck & Co., (13-329) — headnotes Malicious Prosecution; Probable Cause; Motion to Dismiss
State v. Bartlett, (13-471) — headnotes Order on motion to suppress material conflict in evidence, written order versus order in open court
State v. Clark, (13-561) — headnotes Premeditation; deliberation; affirmative defenses
State v. Holloman, (13-559) — headnotes Constitutional Law, effective assistance of counsel; request for appointment of substitute counsel; double jeopardy punishment for both kidnapping and underlying sexual assault
State v. Jones, (13-215) — headnotes whether it is error to use the term victim during jury instruction and during closing argument
State v. Lewis, (13-254) — headnotes Credit for pretrial confinement
State v. Paul, (13-717) — headnotes Law of the case; resentencing; new evidence
State v. Rollins, (13-362) — headnotes N.C.G.S. 15-166
State v. Rowe, (13-308) — headnotes Assault inflicting serious injury; Acting in concert; Jury instruction or lesser-8included offense; Jail fees
State v. Weaver, (13-578) — headnotes State actor; security guard
THZ Holdings, LLC v. McCrea, (13-425) — headnotes Breach of trust; reappointment of trustee.
Tong v. Dunn, (12-1261) — headnotes Claim-splitting and res judicata
Wetherington v. N.C. Dep't of Crime Control & Pub. Safety, (13-405) — headnotes Administrative Appeal - State Personnel Commission - Just Cause for Dismissal
Unpublished Opinions - Rule 30e - Zip File of Unpublished Opinions
Beck Elec., LLC v. Neighboring Concepts, PLLC, (13-391) Binder v. Binder, (13-522) Brigman v. Mcfetridge, (13-741) Church v. Decker, (13-456) Clark v. Clark, (13-612) Fields v. Harnett Cnty., (13-761) Flowers v. Williams, (13-535) Fox v. City of Greensboro, (13-171-2) Garmon v. Hagans, (13-441) Holly Springs Hosp. II, Inc. v. N.C. Dep't of Health & Human Servs., (13-367) In re C.A.S., (13-571) In re Hull Story Retail Grp., (13-198) In re Razack, (13-342) In re S.A., (13-675) In re T.V.C.D., (13-861) Moore v. The Goodyear Tire & Rubber Co., (12-1212) State v. Alston, (13-462) State v. Dye, (13-366) State v. Euston, (13-576) State v. Givens, (13-465) State v. Haggins, (13-671) State v. Harris, (13-212) State v. Johnson, (12-932) State v. Jones, (13-676) State v. Owens, (13-321) State v. Smith, (13-293) State v. Turner, (13-395) State v. Whitaker, (13-370)
3 December 2013 Zip File of Published Opinions Mandate: 23 December 2013 Case Title / Description
Caromont Health, Inc. v. N.C. Dep't of Health & Human Servs., (12-1044) — headnotes CON; substantial prejudice
Espinosa v. Tradesource, Inc., (13-220) — headnotes Adaptive Housing; Retroactive Attendant Care; Cost of Life Care Plan; Attorneys' Fees; Industrial Commission Rules for Rehabilitation Professionals; Post-Appeal Motions at Industrial Commission
Espinosa v. Tradesource, Inc., (13-466) — headnotes Adaptive Housing; Retroactive Attendant Care; Cost of Life Care Plan, Attorneys' Fees; Industrial Commission Rules for Rehabilitation Professionals; Post-Appeal Motions at Industrial Commission
Gary v. Bright, (13-687) — headnotes Custody modification; substantial change in circumstances
GE Betz Inc. v. Conrad, (13-239) — headnotes Unfair or deceptive practices, reasonableness of attorneys' fees, criminal contempt
Halstead v. Plymale, (13-375) — headnotes Wills; Testator's Intent
Hennessey v. Duckworth, (13-629) — headnotes Attorney's fees; N.C.G.S. § 50-13
Herring v. Herring, (13-544) — headnotes Motion to set aside separation agreement; Mutual mistake
High Point Bank & Trust Co. v Highmark Props., LLC, (13-331) — headnotes Guarantor; N.C.G.S. Sec. 45-21.36; offset defense
Holmes v. Solon Automated Servs., (13-325) — headnotes Workers' Compensation; Frustration of purpose; Restitution
Home Trust Bank v. Green, (13-511) — headnotes mortgage foreclosure hearing notice
In re A.D.N., (13-709) — headnotes Standing to file termination of parental rights petition
In re Webb, (13-324) — headnotes Foreclosure; standing; holder of note; real party in interest; appeal to superior court
John Wm. Brown Co., Inc. v. SECU, (13-388) — headnotes Laches, equitable estoppel
N.C. State Bd. of Educ. v. N.C. Learns, Inc., (13-179) — headnotes Directory statute, jurisdictional statute, State Board of Education, Office of Administrative Hearings, interventior of parties, amendment of the record, charter schools
Podrebarac v. Perry, Bundy, Plyler, Long & Cox, LLP, (13-534) — headnotes Motion to dismiss; Statute of limitations; Legal malpractice
Simon v. Simon, (13-249) — headnotes Equitable distribution; commission; bonus; attorney fees
Stainless Valve Co. v. Safefresh Techs., LLC, (13-144) — headnotes Summary Judgment; Actual Authority; Manager of LLC.
State v. Allah, (13-667) — headnotes First Degree Burglary; Sufficiency of the Evidence of Defendant?s Intent to Commit a Felony Within the Structure Entered; Validity of Visitation-Related Condition of Probation
State v. Benters, (13-305) — headnotes Motion to suppress, evidence, search warrant
State v. Dahlquist, (13-276) — headnotes Fourth Amendment; warrantless search; exigent circumstances; withdrawal of a blood sample; DUI; totality of the circumstances
State v. Gosnell, (13-614) — headnotes Plain error - jury instruction - first-degree murder- premeditation and deliberation Jury instruction - first-degree murder - lying in wait
State v. Hatcher, (13-632) — headnotes Sufficiency of the evidence; Second degree murder; Involuntary manslaughter; Remanding for judgment on a lesser included offense
State v. Jones, (13-286) — headnotes satellite-based monitoring (SBM); ex post facto law; search and seizure
State v. Lalinde, (13-115) — headnotes Jurisdiction; felonious restraint based on fraud
State v. Powell, (13-593) — headnotes maximum month sentencing correction; correction of defendant's prior record level point calculation
State v. Stewart, (13-283) — headnotes admissibility of evidence under Rules 401, 402, 403 (photographs & testimony); motion to dismiss - sufficiency of evidence
Tovar-Mauricio v. T.R. Driscoll, Inc., (13-517) — headnotes Workers Compensation-Insurance Policy-Plain Language; Workers Compensation-scope of review; Workers Compensation-G.S. 97-86.1(d) Reimbursement
Wise v. Alcoa, Inc., (13-29) — headnotes Industrial Commission, Expert Testimony
Unpublished Opinions - Rule 30e - Zip File of Unpublished Opinions
Church v. Decker, (13-455) Frye Reg'l Med. Ctr., Inc. v. Hostetter & Keach, Inc., (13-313) Greer State Bank v. Evans, (13-560) Hedgepeth v. Winston-Salem State Univ., (13-577) In re D.P.W., (13-806) In re Hendrick, (13-284) In re J.A.R., (13-636) In re L.G., (13-875) MacMillan v. Thompson, (13-611) N.C. State Bar v. Burford, (13-647) Pace v. State of N.C., (13-252) Raynor v. N.C. Dep't of Crime Control & Pub. Safety, (13-197) Rettig v. Rettig, (13-287) Skipper v. Wayne Oil Co., Inc., (13-657) State v. Addison, (13-145) State v. Albright, (13-763) State v. Bowden, (13-290) State v. Brennick, (13-627) State v. Brice, (13-363) State v. Brincefield, (13-434) State v. Bullock, (13-514) State v. Caldwell, (13-272) State v. Cheek, (13-783) State v. Compel, (13-730) State v. Eggleston, (13-185) State v. Gatewood, (13-669) State v. Glaspie, (13-123) State v. Grubb, (13-625) State v. Hill, (13-106) State v. Lewis, (13-418) State v. Maske, (13-120) State v. Merrell, (13-244) State v. Mills, (13-867) State v. Moody, (13-122) State v. Morton, (13-146) State v. Rankin, (13-234) State v. Robinson, (13-415) State v. Roundtree, (13-633) State v. Rumley, (13-408) State v. Skeens, (13-595) State v. Smith, (13-15) State v. Williams, (12-1097) State v. Yelverton, (13-211) Strickland v. Goetz, (13-605) Vogel v. Health Scis. Found., Inc., (13-303) Wahl v. Porter, (13-333)
19 November 2013 Zip File of Published Opinions Mandate: 9 December 2013 Case Title / Description
Atl. Coast Conference v. Univ. of Maryland, (13-532) — headnotes Sovereign Immunity; Comity; Interlocutory Orders
Auto. Grp., LLC v. A-1 Auto Charlotte, LLC, (13-608) — headnotes res judicata; new circumstances, Rule 59(a)(8)
Bank of Am., N.A. v. Rice, (13-180) — headnotes Novations; Promissory Note; Contract construction
Brown v. Cavit Scis., Inc., (13-165) — headnotes Rule 60(b) motion to set aside default judgment; irregular judgment; sufficiency of complaint to allege claims against defaulting party
Dep't of Transp. v. Webster, (12-1546) — headnotes Interlocutory order; eminent domain; police power; admissibility of evidence
Duplin Cnty. DSS on behalf of Pulley v. Frazier, (13-619) — headnotes Child support arrearages; Motion to set aside judgment
Estate of Vaughn v. Pike Elec., LLC, (13-448) — headnotes The exclusivity provision of the Workers' Compensation Act. Appellate jurisdiction over denials of motions to dismiss under Rules 12(b)(1) and 12(b)(6). Woodson & Pleasant exceptions
Frazier v. Carolina Coastal Ry., Inc., (13-426) — headnotes Railroad crossing; contributory negligence, summary judgment
In re G.C., (13-152) — headnotes Release Pending Appeal; Juvenile Proceedings
In re J.P., (13-35-2) — headnotes Waiver of Notice for Permanency Plan Hearing; Sufficiency of Visitation Plan; Sufficiency of Findings
In re T.J.F., (13-707) — headnotes Grounds for terminating parental rights; Notice
JPMorgan Chase Bank v. Browning, (13-358) — headnotes Unjust Enrichment; Deed of Trust; Leave to Amend
Mills v. Triangle Yellow Transit, (13-617) — headnotes Workers Compensation; three or more employees
State v. Chukwu, (13-315) — headnotes Competency; Findings of Fact
State v. Martin, (13-374) — headnotes Prior Record Level; Rule 9(a)
State v. Northington, (13-475) — headnotes Prejudicial Error, Sentencing Points
State v. Shannon, (13-214) — headnotes Motion to Dismiss; Intimidating a Witness; Prospective Witness
State v. Williams, (13-246) — headnotes Probation Revocation; Subject Matter Jurisdiction
Unpublished Opinions - Rule 30e - Zip File of Unpublished Opinions
Allmond v. Goodnight, (12-1270) Dep't of Transp. v. Ashcroft Commoms, LLC, (13-140) Gentry v. Miller, (13-581) Historical Pres. Action Comm., Inc. v. City of Reidsville, (12-1386) In re A.B.D., (13-641) In re A.N.V., (13-572) In re D.M.R., (13-789) In re E.L.F., (13-604) In re J.B.W., (13-445) In re K.C., (13-738) In re M.F., (13-432) In re M.S.M.K.R., (13-737) In re R.C., (13-683) In re T.F., (13-731) In re T.R.C., (13-508) McRavion v. N.C. Dep't Of Corr., (13-467) State v. Brown, (13-501) State v. Church, (13-557) State v. Goodwin, (13-569) State v. Harris, (13-479) State v. Hart, (13-558) State v. Johnson, (13-368) State v. Lawson, (13-529) State v. Newson, (13-131) State v. Nicholas, (13-613) State v. Nunn, (13-528) State v. Rossi, (13-361) State v. Salter, (13-386) State v. Samolinski, (13-485) State v. Streater, (13-338) State v. Wigfall, (13-523) State v. Wilson, (13-110) Thornton v. City of Raleigh, (13-533)
5 November 2013 Zip File of Published Opinions Mandate: 25 November 2013 Case Title / Description
Busik v. N.C. Coastal Res. Comm'n, (12-1491) — headnotes Coastal Area Management Act; Setback requirements; Contested Case Hearing; Coastal Resource Commission; Interpretation of Setback Rules
Chaffins v. Tar Heel Capital Corp., (13-332) — headnotes medical causation; workers' compensation
Estate of Hurst v. Jones, (12-758) — headnotes Uniform Fraudulent Transfer Act
Farlow v. Brookbank, (13-403) — headnotes Suit for Legal Fees; Interest on Open Account; Sufficiency of Notice
First Fed. Bank v. Aldridge, (13-450) — headnotes Civil Procedure; Pleadings; Rule 12(b)(6); Rule 15(a)
In re C.M., (13-546) — headnotes Competent evidence; Permanency planning
In re E.G.M., (13-584) — headnotes Subject matter jurisdiction, Indian Child Welfare Act
In re J.L.H., (13-385) — headnotes Extension of Commitment; Mootness; Sufficiency of Oral Notice
In re M.M., (13-600) — headnotes Inconvenient forum; Necessary findings of fact; Terminating review hearings; Visitation
In re Town of Smithfield, (13-435) — headnotes Electric Supplier Agreements; N.C.G.S. 160A-331.2(a); Statutory construction
In re Twin Cnty. Motorsports, Inc., (13-21) — headnotes Representation of corporations; DMV Hearings
In re will of McNeil, (13-451) — headnotes Summary judgment; Undue influence; Testamentary capacity
Irving v. Charlotte-Mecklenburg Bd. of Educ., (12-1496) — headnotes Public shool activity bus; Tort Claims Act; Negligence; N.C.G.S. Sec. 143-300.1
Johnson v. Johnson, (12-977) — headnotes Equitable Distribution, Defined Benefit Plan, Unequal Distribution
Kreuger v. N.C. Criminal Justice Educ. & Training Standards Comm'n, (13-288) — headnotes Law Enforcement Certification; Due process; Equal protection
Lipinski v. Town of Summerfield, (13-468) — headnotes zoning-procedural due process-notice and an opportunity to be heard; zoning-interpretation of an ordinance
Mathis v. Dowling, (13-380) — headnotes Malicious prosecution, independent investigation
Rockford-Cohen Grp., LLC v. N.C. Dep't of Ins., (13-124) — headnotes Interlocutory Appeal-substantial right-right to do business; N.C. Constitution-prohibition on monopolies and perpetuities
State v. Bryan, (13-520) — headnotes N.C.G.S. 15A-1432,N.C.G.S.15-1445, appeal from final judgment of district court
State v. High, (12-1549) — headnotes Jurisdiction, period of probation, extension of probation
State v. Holland, (12-1447) — headnotes Competency to stand trial; failure to inquire sua sponte; motion for appropriate relief; competency; failure to inquire sua sponte
State v. James, (13-353) — headnotes Batson objection, racial make-up of jury, findings of fact
State v. Malunda, (13-372) — headnotes search and seizure; probable cause
State v. Martinez, (13-492) — headnotes N.C.G.S. Sec. 14-221.2 - Altering court documents; sufficiency of the evidence
State v. May, (13-37) — headnotes N.C. CONST. art. I, § 24; coerced jury verdict; standard of review; expert witness; opinion evidence; Rule 404(b) other crimes evidence
State v. Phillips, (13-449) — headnotes Standard of proof, findings of fact, criminal contempt order
State v. Smith, (13-463) — headnotes Reportable conviction for sex offender registry
Washington v. Cline, (13-224) — headnotes Service of process
Unpublished Opinions - Rule 30e - Zip File of Unpublished Opinions
Atkinson v. Reikowsy, (13-526) Bass v. Harnett Cnty., (13-356) Bhathela v. Currie, (13-319) Branch Banking & Trust Co. v. Harris, (13-489) Coats v. N.C. Dep't of Health & Human Servs., (13-275) Coraldi v. Pickett, (13-43) FSI, Inc. v. Newson, (13-222) FSI, Inc. v. Newson, (13-219) Guilford Cnty. v. Sutton, (13-310) Hollifield v. Commc'ns Installations Specialists, (13-378) In re A.S.B., (13-400) In re B.G.A.S., (13-583) In re B.O., (13-568) In re J.N.M., (13-567) In re Jerry's Shell, LLC, (13-223) In re K.G., (13-505) In re S.E.W., (13-582) In re S.J.S., (13-682) In re S.R., (13-644) Liberatore v. Liberatore, (12-1571) Moore v. G & I VI Forest Hills GP, LLC, (13-3) Powell's Med. Facil. v N.C. Dep, (13-166) Quackenbush v. Steelman, (13-240) Robinson v. Discovery Ins. Co., (13-226) State v. Best, (13-498) State v. Bowman, (12-1565) State v. Bradley, (13-524) State v. Bryant, (13-440) State v. Carson, (13-235) State v. Carver, (13-592) State v. Chaplin, (13-393) State v. Childress, (13-470) State v. Collins, (13-410) State v. Greene, (13-245) State v. Haley, (13-261) State v. Hall, (13-154) State v. Larson, (13-163) State v. Lee, (13-205) State v. Lewis, (13-555) State v. Long, (13-347) State v. Matthews, (13-277) State v. Miller, (13-216) State v. Muir, (13-267) State v. Norris, (13-282) State v. Ownbey, (13-407) State v. Shackleford, (13-548) State v. Wiggins, (13-233) State v. Wiley, (13-409) Stevens v. United States Cold Storage, Inc., (13-150) Thompson v. Gutierrez, (13-59)
15 October 2013 Zip File of Published Opinions Mandate: 4 November 2013 Case Title / Description
City of Asheville v. Resurgence Dev. Co., LLC, (13-341) — headnotes Public use or benefit; Eminent domain
Davis v. Woodlake Partners, LLC, (13-236) — headnotes Summary Judgment; Statute of Limitations; Contract Under Seal
Johnson v. Crossroads Ford, Inc., (13-173) — headnotes summary judgment, wrongful termination, age discrimination, affidavits
State v. Blankenship, (12-1560) — headnotes Motion to Suppress; Anonymous tip; Reasonable suspicion
State v. Simpson, (13-253) — headnotes Motion to Dismiss - Sufficiency of the evidence of maintaining a vehicle for keeping or selling methamphetamine; Jury Instructions - G.S. 90-87(15); Sentencing - Double Jeopardy
State v. Thomas, (13-175) — headnotes Jury selection, voir dire, peremptory challenge
Zaldana v. Smith, (13-318) — headnotes Workers' Compensation; Refusal to Renew
Unpublished Opinions - Rule 30e - Zip File of Unpublished Opinions
Alston v. N.C. A & T State Univ., (13-137) BB&T v. Bing, (13-184) Ellis v. Ellis, (13-351) First Bank v. S&R Grandview, L.L.C., (13-343) Foot Locker, Inc. v. Best, (13-248) Ford v. City of Wilson, (13-376) Harvell v. Wix Filtration, LLC, (13-100) In re D.C., (13-502) In re E.G., (13-538) In re J.D.M., (13-491) In re R.N.H., (13-506) Lynch v. Oak Island Beach Villa Owners Ass'n, Inc., (13-177) Morales v. Morales, (13-406) Morgan v. Morgan, (13-134) Skanska USA Bldg., Inc. v. Blythe Dev. Co., (13-314) Smith v. Parker, (13-269) Smith v. Smith, (13-459) State v. Adams, (13-153) State v. Allison, (13-129) State v. Autery, (13-348) State v. Barnes, (13-417) State v. Barnes, (13-354) State v. Blackwell, (13-296) State v. Boykin, (13-487) State v. Coleman, (13-373) State v. Earnhardt, (12-1441) State v. El, (13-295) State v. Foote, (13-334) State v. Garner, (13-182) State v. Goldman, (12-1509) State v. Gregory, (13-416) State v. Gresham, (13-326) State v. Horn, (13-141) State v. Jackson, (13-357) State v. Jolly, (12-1389) State v. Lewis, (13-309) State v. Lillie, (13-390) State v. Lukowitsch, (13-133) State v. McDonald, (13-210) State v. McMillan, (13-527) State v. Mills, (13-497) State v. Mott, (13-88) State v. Patterson, (13-114) State v. Rich, (13-299) State v. Scott, (13-345) State v. Smith, (13-473) State v. Strickland, (13-484) State v. Thompson, (13-438) State v. Tomlinson, (13-398) State v. Toomer, (13-541) State v. Troxler, (13-79) State v. Vaughn, (11-751-2) State v. Villanueva, (13-116) State v. Walton, (13-203) State v. Washington, (13-108) State v. Weichelt, (13-111) State v. Williams, (13-47) Walker v. N.C. Dep't Of Corr., (13-476) Walker v. N.C. Dep't Of Corr., (13-477) Ward v. Carmona, (13-258) WRI/Raleigh LP v. Richardson, (13-291)
1 October 2013 Zip File of Published Opinions Mandate: 21 October 2013 Case Title / Description
Charlotte Motor Speedway, LLC v. Cnty. of Cabarrus, (12-1361) — headnotes Indefiniteness; Rule 12(b)(6); Fraud; Negligent misrepresentation
In re Cline, (12-964) — headnotes Removal of District Attorney, Discovery, Burden of Proof, Statutory Vagueness, Free Speech
Ross v. Ross, (12-1141) — headnotes equitable distribution; classification and valuation of property; source of funds; pre-marriage contribution; post-marriage payments divisible property; passive appreciation
State v. Ashe, (13-298) — headnotes Competence to stand trial; Sua Sponte hearing; Due process
State v. Call, (13-266) — headnotes Testimonial evidence; unavailability of declarant
State v. Davis, (13-317) — headnotes Motion to Dismiss - sufficiency of the evidence - food stamp fraud (G.S. 108A-53(a)) Jury Instructions - plain error review
State v. Grooms, (12-1183) — headnotes Rule 404(b) evidence; second degree murder based on impaired driving
State v. Monroe, (13-232) — headnotes Admission of evidence; closing arguments; jury instructions
Unpublished Opinions - Rule 30e - Zip File of Unpublished Opinions
Americus Retail Holdings, LLC v. Ball, (13-281) Cebula v. The Givens Estates, Inc., (13-242) Diamond v. Charlotte-Mecklenburg Cnty. Bd. of Educ., (12-690-2) Elizabeth Townes Homeowners Ass'n, Inc. v. Jordan, (13-262) Fed. Nat'l Mtge. Ass'n v. McLean, (13-364) Fox v. City of Greensboro, (13-171) In re Gordon, (13-322) In re J.K.C., (13-136) In re N.J., (13-53) In re R.B., (13-503) In re Radisi, (13-285) In re Z.A., (13-457) Irving v. Charlotte-Mecklenburg Bd. Of Educ., (13-34) Owen v. Hogsed, (13-157) Raymond v. N.C. Police Benevolent Ass'n, Inc., (13-192) State v. Carter, (12-1550) State v. Chester, (12-1487) State v. Chestnut, (13-32) State v. Cyr, (13-183) State v. Frye, (12-1507) State v. Holmes, (12-1580) State v. Mayweather, (13-316) State v. Meadows, (12-1539) State v. Moore, (13-135) State v. Parker, (13-97) State v. Rambert, (12-1558) State v. Ramos, (13-255) State v. Sutton, (13-229) State v. Watkins, (13-56) State v. Watts, (13-24) Walker v. N.C. Dep't of Corr., (13-189)
17 September 2013 Zip File of Published Opinions Mandate: 7 October 2013 Case Title / Description
Davis v. Davis, (13-113) — headnotes Modification to custody; Visitation; Necessary findings; Contempt
Hill v. Hill, (12-1155) — headnotes Equitable Distribution, Failure to Classify, Failure to Value, Distributional Factors
Mancuso v. Burton Farm Dev. Co. LLC, (13-38) — headnotes Real Estate Purchase; Enforceability of Non-Contractual Representations
Robert K. Ward Living Trust v. Peck, (13-125) — headnotes North Carolina General Statute ? 36C-10-1005; Breach of trust
State v. Barbour, (12-990) — headnotes Verdict Sheet, Closing Argument, Right to Remain Silent
State v. Barnes, (13-76) — headnotes Possession of Controlled Substance in Local Confinement Facility; Nature of Voluntary Act Necessary for Finding of Guilt
State v. Boyett, (12-222-2) — headnotes Reconvening order; plain error; jury instruction; attempted second-degree rape and attempted incest
State v. Carr, (13-259) — headnotes July challenge for cause
State v. Fish, (13-11) — headnotes Felony larceny; Conspiracy; Fair market value
State v. Jackson, (12-1533) — headnotes Ineffective assistance of counsel; GPS tracking evidence; hearsay; in-court identification
State v. Kirkwood, (12-1359) — headnotes Discharging weapon into occupied property
State v. Marlow, (13-18) — headnotes Stipulations; double jeopardy; lesser included offense; lifetime SBM
State v. Marsh, (13-190) — headnotes Motion for appropriate relief; Extranseous evidence before jurors
State v. Tinney, (13-209) — headnotes Invalid Plea Term; Sufficient Advice by Court; Voluntary Plea
State v. Watkins, (13-260) — headnotes Prayer for Judgment Continued for sentencing; Unreasonable delay jurisdiction
Wilkerson v. Duke Univ., (13-181) — headnotes False Imprisonment; Assault; Negligent Supervision; Motion to Amend Complaint
Unpublished Opinions - Rule 30e - Zip File of Unpublished Opinions
Craft v. City Of New Bern, (13-148) Ennis v. Munn, (12-1349) James v. Schoonderwoerd, (12-1457) Myers v. Ben Mynatt Chevrolet Cadillac, (12-1211) N.C. Bd. of Pharmacy v. Najarian, (12-1140) Okitenbo v. Charlotte Mecklenburg Sch., (13-349) Premiere Auto, L.L.C. v. Wachovia Bank, N.A., (13-328) State v. Alsbrooks, (13-414) State v. Austin, (13-268) State v. Blanton, (12-1517) State v. Everette, (12-1500) State v. Garrett, (13-206) State v. Inman, (12-1561) State v. Jennings, (13-411) State v. Jones, (13-6) State v. Jones, (12-1320) State v. McClain, (13-371) State v. McKenzie, (13-294) State v. Meggett, (13-107) State v. Morris, (13-99) State v. Najjar, (13-204) State v. Peacock, (13-187) State v. Phillips, (13-231) State v. Shah, (13-307) State v. Smith, (13-397) State v. Tolson, (13-121) State v. Wiggs, (12-1529) White v. Burton Farm Dev. Co. LLC, (12-1407)
3 September 2013 Zip File of Published Opinions Mandate: 23 September 2013 Case Title / Description
Burnham v. S & L Sawmill, Inc., (12-1581) — headnotes Premises Liability; Necessity to Take Affirmative Action to Protect Person Lawfully on Premises; Non-Delegable Duty Doctrine
Gilmore v. Gilmore, (12-1426) — headnotes No civil cause of action based on perjury; failure to state a claim under N.C. RICO Act
Hammond v. Saini, (12-1493) — headnotes Medical review privilege; work product doctrine
In re Bullock, (13-149) — headnotes Involuntary commitment; Insanity acquittees; Recommitment hearing; Adequate findings
Kane v. N.C. Teachers & State Emps. Comprehensive Major Med. Plan, (13-73) — headnotes Exhaustion of administrative remedies
Medlin v. Weaver Cooke Constr., LLC, (13-159) — headnotes Industrial Commission; terminating compensation; causation between injury and wage loss.
State v. Cooper, (12-926) — headnotes Expert witness, qualifications, discovery violations, sanction, disclosure
State v. Gaston, (13-1) — headnotes Voluntary manslaughter; self-defense; jury instructions
State v. Gibert, (12-1087) — headnotes Short form indictment for attempted statutory rape
State v. Verkerk, (12-1579) — headnotes Search and Seizure; Governmental Action or Private Person; Standard for Use in Evaluating Search by Governmental Actor Other than a Law Enforcement Officer
Town of Midland v. Wayne, (12-1163) — headnotes Condemnation; inverse condemnation; temporary taking; easement; regulatory taking; vested right; compensation expert opinion testimony; unity of ownership
Unpublished Opinions - Rule 30e - Zip File of Unpublished Opinions
ABC Roofing, Inc. v. Sawyer, (13-241) Bost Constr. Co. v. Blondy, (12-1454) Culbreth v. Ironmen of Fayetteville, Inc., (13-14) In re A.H.L., (13-172) In re C.L.Y., (12-1570) Mintz v. Kelley, (13-36) Moorefield v. Moorefield, (13-91) N.C. State Bar v. Small, (12-1545) Pugh Oil Co., Inc. v. Ace Transp., Ltd, (12-1438) State v. Bivens, (12-1462) State v. Boyd, (10-1072-3) State v. Brown, (13-77) State v. Bryant, (13-62) State v. Cates, (12-1055) State v. Christian, (13-162) State v. Evans, (12-1423) State v. Harris, (12-1532) State v. Helms, (12-1436) State v. Malachi, (13-45) State v. Nieves, (12-1277) State v. Nixon, (12-1439) State v. Roby, (13-61) State v. Weiss, (12-1566) State v. Williams, (13-193) State v. Wilson, (13-70) Weber, Hodges, & Godwin Commercial Real Estate Servs., LLC v. Hartley, (13-207)
20 August 2013 Zip File of Published Opinions Mandate: 9 September 2013 Case Title / Description
Barbour v. Pate, (13-227) — headnotes Easement Implied by Prior Use; Easement by Necessity; Easement by Prescription
Barnes v. Cortez, (12-1427) bail bond forfeitures
In re A.S., (13-42) — headnotes Parental rights, child custody, mootness
In re forclosure of Raynor, (12-1116) — headnotes Foreclosure; Res Judicata
Kohn v. Firsthealth of the Carolinas, Inc., (13-168) — headnotes Public Utility Doctrine
Lunsford v. Mills, (13-167) — headnotes Underinsured motorist (UIM) coverage; multiple tortfeasors; N.C. Gen. Stat. § 20-279.21(b)(4)
Morris v. Scenera Research, LLC, (12-1481) — headnotes North Carolina Wage & Hour Act; North Carolina Retaliatory Employment Discrimination Act; Damages, Attorneys' Fees; Rescission
Myers Park Homeowners Ass'n, Inc. v. City of Charlotte, (12-1346) — headnotes Zoning ordinance; Rules 52 and 59 motions
Nieto-Espinoza v. Lowder Constr., Inc., (12-1316) — headnotes Workers' Compensation; excusable neglect; waiver
RL Regi N.C., LLC v. Lighthouse Cove, LLC, (12-1279) — headnotes Equal Credit Opportunity Act's Regulation B; discrimination of the basis of marital status; violation of ECOA as affirmative defense; forbearance agreement
Robinson v. Duke Univ. Health Sys., Inc., (12-1239) — headnotes Summary judgment; professional malpractice
State v. Agustin, (12-1065) — headnotes Plain error, Lesser included offense, Rape of a child.
State v. Bowden, (12-1072) — headnotes Sentencing; findings of fact; conclusions of law; motion for appropriate relief
State v. Cortez, (12-1399) — headnotes bail bond forfeitures
State v. Green, (12-1466) — headnotes 404(b) evidence; first-degree sexual offense; lifetime sex offender and SBM registration
State v. Knudsen, (12-1475) — headnotes Search and Seizure; Fourth Amendment; Competency of evidence; Reasonable suspicion
State v. Marino, (12-1422) — headnotes Closing argument; discovery; Brady material; Sixth Amendment confrontation clause; motion for appropriate relief.
State v. Murray, (12-1066) — headnotes Authentication of photographs; relevancy and prejudice of erroneously admitted photographs
State v. Packingham, (12-1287) — headnotes First Amendment, social networking web site
State v. Perry, (13-30) — headnotes Admissibility of Expert Testimony Challenged as Insufficiently Reliable Given New Information; Sufficiency of the Evidence
State v. Presson, (12-1518) — headnotes Motion to dismiss; jury instruction; self-defense; jury request to review testimony
State v. Tatum-Wade, (12-1568) — headnotes Evidence of defendant's character trait for trusting others under Rule 404(a)(1)
State v. Walston, (12-1377) — headnotes Evidence-good character; Rule 702, expert testimony; Rule 404(b), prior bad acts evidence; Jury Instructions-use of victim
Tyll v. Willets, (13-105) — headnotes 50C No-contact order
Wellons v. White, (12-1205) — headnotes Grandparent Visitation; Child Custody; Standing; Law of the Case; Collateral Attacks; Contempt
White v. Cochran, (13-155) — headnotes Governmental Immunity; Waiver by Purchase of Insurance; Adequacy of Notice Claim
Unpublished Opinions - Rule 30e - Zip File of Unpublished Opinions
Bryant v. AP Indus., (12-1456) Cnty. of Durham, ex rel v. Orr, (13-109) Coleman v. Orr, (13-8) Duke Univ. Health Sys., Inc. v. Sparrow, (13-12) Edgerton v. Oliver, (12-1455) Good v. Omega V, LLC, (12-1490) In re A.S., (13-147) In re A.W., (13-161) In re G.P.C., (13-327) In re K.B.G., (13-160) In re L.L., (13-454) In re N.B., (13-419) In re S.E.A., (13-225) In re S.S., (13-420) In re T.P., (13-280) State v. Boshers, (12-1344) State v. Divinie, (12-1311) State v. Ellerbee, (12-1007) State v. Miller, (13-54) State v. Moreno, (12-1402) State v. Robinson, (12-1578) State v. Sammons, (12-1522) State v. Todd, (13-67) Tedder v. High, (12-1397) Tincher v. Adecco, (12-1153)
6 August 2013 Zip File of Published Opinions Mandate: 26 August 2013 Case Title / Description
Barker v. Barker, (12-1551) — headnotes Civil Contempt
Estate of Hurst v. Moorehead I, LLC, (12-1285) — headnotes Personal liability of member of LLC for corporate's breach of contract; piercing the corporate veil; LLC member's individual liability for unfair and deceptive trade practice
Grich v. Mantelco, LLC, (13-169) — headnotes Motion to Dismiss; release; claim for damages
Hamilton v. Johnson, (13-63) — headnotes Service of process; deliver to addressee, Rule 4
In re D.E.G., (13-279) — headnotes Cessation of Reunification Efforts; Allowing Withdrawal of Respondent's Attorney Without Proper Notice
In re foreclosure of Manning, (12-1247) — headnotes Foreclosure
Integon Nat'l Ins. Co. v. Villafranco, (13-82) — headnotes Automobile Insurance; Contract Interpretation; Material Misrepresentation
Izydore v. City of Durham, (12-1284) — headnotes Authority under N.C. Gen. Stat 6-19.1 to tax local governmental units with attorney's fees.
Kelly v. Kelly, (12-1582) — headnotes Motion to modify; Alimony; Required findings of fact
Lendingtree, LLC v. Anderson, (12-1266) — headnotes Venue; Forum-Selection Clauses; Waiver; Delay; Statute of Limitations
Lentz v. Phil's Toy Store, (12-1395) — headnotes Industrial Commission; subject matter jurisdiction
Outdoor Lighting Perspectives Franchising, Inc. v. Harders, (12-1204) — headnotes Preliminary Injunction; Enforcement of Non-Competition Agreement Between Franchisor and Franchisee; Geographic Scope and Extent of Prohibited Activities
Riggings Homeowners, Inc. v. Coastal Res. Comm'n, (12-1299) — headnotes Coastal Resources Commission; Variance Requests; Unnecessary Hardships; Balancing Interests; Erosion; Temporary Erosion Control Structures; Sandbags
Simmons v. Kross Lieberman & Stone, Inc., (13-10) — headnotes Unfair debt collection practices, N.C. Gen. Stat. § 58-70-115(3), N.C. Gen. Stat. § 58-70-130, actual damages, statutory penalty
State v. Bacon, (12-1486) — headnotes Evidence Supporting Aggravating Factor
State v. Barrett, (12-1530) — headnotes Corroborating testimony; Rule 404(b); clerical error
State v. Blackwell, (12-1472) — headnotes Coercion of jury verdict; Motion for continuance
State v. Chapman, (11-229-2) — headnotes First-degree murder; previable fetus; habeas corpus
State v. Derbyshire, (12-1382) — headnotes Reasonable suspicion to justify Terry stop of vehicle.
State v. Evans, (13-17) — headnotes Jury Instructions; Motion to Dismiss
State v. Fisher, (12-1404) — headnotes Involuntary Manslaughter; Sufficiency of the Evidence; Proximate Cause Instruction
State v. Frady, (12-1375) — headnotes Child sexual abuse; expert testimony; prejudicial error
State v. Harwood, (12-1301) — headnotes Motion for Appropriate Relief; Question of First Impression; No Change in Law
State v. Martin, (12-1574) — headnotes Totality of circumstances; motion to suppress; voluntary confession
State v. McCoy, (12-1210) — headnotes In camera review of sealed records; Admissibility of evidence of third-party guilt
State v. Miller, (13-81) — headnotes Fourth Amendment; Dog Sniff; Plain view exception.
State v. Oliphant, (12-1219) — headnotes Jury instruction; sufficiency of the evidence; cross-examination
State v. Pennell, (12-1269) — headnotes Appeal after probation revocation; jurisdiction; indictment
State v. Summey, (12-1405) — headnotes Expression of Opinion by Trial Court; Coercion of Verdict
State v. Wray, (12-1406) — headnotes Right to counsel; Sentencing
Time Warner Entm't Advance/Newhouse P'ship v. Town of Landis, (13-22) — headnotes Subject Matter Jurisdiction; Controversy Requirement; Pole Attachment Agreements; Just, Reasonable and Non-Discriminatory Rates
Tinsley v. City of Charlotte, (12-1543) — headnotes Industrial Commission jurisdiction; attorneys' fees; equal protection
Warrender v. Gull Harbor Yacht Club, Inc., (12-1038) — headnotes Restrictive covenants; Tortious interference with a contract; Riparian rights; Necessary parties; Nonprofit corporation member liability; Attorneys' fees
Watkins v. Watkins, (12-1135) — headnotes Equitable distribution, retirement accounts, coverture fraction, N.C. Gen. Stat. § 50-20.1
Williams v. Williams, (13-55) — headnotes Motion to disqualify counsel; conflict of interest; representation of estate administrator in both official and individual capacity
Yeager v. Yeager, (13-86) — headnotes Quiet title; Cancellation of Deeds of Trust; Mootness
Unpublished Opinions - Rule 30e - Zip File of Unpublished Opinions
Bell & Watson Telecom Consulting Grp., Inc. v. Knaus, (12-1036) Branch Banking & Trust Co. v. Peacock Farm, Inc., (12-1494) Daly v. Daly, (12-1453) Debaun v. Kuszaj, (12-1520) Ferguson v. Richard Childress Racing Enters., (13-130) In re A.D., (13-72) In re A.G.T., (13-320) In re A.V., (13-292) In re A.W., (13-311) In re D.C., (12-1431) In re foreclosure of Shaw, (12-1380) In re J.M.W., (13-237) In re J.R.L., (13-238) In re M.A.W., (13-304) In re Q.H., (13-188) In re R.A.M., (13-271) In re S.R.H., (12-1363) Jackson v. Cape Fear Turf Farm, Inc., (12-1347) Lockerman v. S. River Elec. Membership Corp., (12-1450) Lockhart v. Tri-State Hous., Ltd., (12-1418) Parker v. Smith, (12-1552) Perry v. Hall, (12-1265) R.H. Donnelley Inc. v. Embarq Corp., (13-119) Rabun Cnty. Bank v. Earnhardt, (13-93) State v. Adams, (12-1434) State v. Armistead, (12-1315) State v. Blount, (12-1465) State v. Corrothers, (12-1569) State v. Fraley, (13-69) State v. Francis, (12-1464) State v. Frazier, (13-5) State v. Gosnell, (12-1328) State v. Grice, (12-1448) State v. Holly, (12-1557) State v. Karmo, (12-1209) State v. Lunsford, (13-94) State v. Massey, (12-1329) State v. McGriff, (13-7) State v. Rankins, (12-1444) State v. Richardson, (12-1130) State v. Smith, (12-1527) State v. Waller, (12-1531) State v. Warrick, (12-1424) State v. Williams, (13-89) State v. Williams, (12-995) Taft v. Dickman, (12-943) Washburn v. Washburn, (12-1364) Washburn v. Washburn, (12-1535) Willis v. Roberts, (12-1471)
16 July 2013 Zip File of Published Opinions Mandate: 5 August 2013 Case Title / Description
Christie v. Hartley Constr., Inc., (12-1385) — headnotes Statute of repose, express warranty
In re Adoption of C.E.Y., (13-65) — headnotes Adoption Proceeding; Consent not Necessary; Transfer.
Mast, Mast, Johnson, Wells & Trimyer, P.A. v. Lane, (12-1378) — headnotes Attorney fees; account stated
McKinney v. McKinney, (12-1152) — headnotes Expert Witness Fees; Attorney Fees
Nowlin v. Moravian Church in Am., (12-1290) — headnotes Negligence; Duty of care owed by a Camp to its Campers
Paradigm Consultants, Ltd. v. Builders Mut. Ins. Co., (12-1576) — headnotes Interlocutory Appeal; Substantial Right; Duty to Defend
State v. Gamez, (12-1488) — headnotes Amendment to N.C. R. Evidence 702; effective date
State v. Gordon, (12-1318) — headnotes NCGS 8C-1, Rule 404(b); requirement of similarity
State v. Kornegay, (13-52) — headnotes Probation revocation; Jurisdiction; Violation reports
State v. Lee, (13-95) — headnotes Resentencing; retroactive application of sentencing grids
State v. Peterson, (12-1047) — headnotes Newly discovered evidence; Misrepresentations of quailifications
State v. Romero, (12-1499) — headnotes Confinement in Response to Violation (CRV), criminal defendant?s right to appeal, N.C.G.S. 15A-1344(d2)
State v. Stevens, (12-1394) — headnotes causing juvenile to be in place or condition whereby juvenile could be adjudicated neglected-sufficiency of the evidence, sufficiency of the indictment; assault on a child under 12; jury instructions
Unpublished Opinions - Rule 30e - Zip File of Unpublished Opinions
Bennett v. House, (13-64) Breede v. Breede, (12-1585) Britt v. West, (12-1519) In re Williams, (13-178) Mountain 1st Bank & Trust v. Galdena, LCC, (12-1322) Rider v. Aderhold, (13-57) Salmony Bank of Am. Corp., (12-1414) Smith v. Smith, (13-151) State v. Cook, (13-33) State v. Core, (13-49) State v. Harris, (13-68) State v. Holliday, (12-1401) State v. Jiggetts, (12-1172) State v. Johnson, (12-1248) State v. Jordan, (12-1264) State v. Seagle, (12-1267) State v. Williams, (12-1376) Whitson v. Camden Cnty. Bd. of Comm'ners, (12-1282) Williamson v. Williamson, (12-1467)
2 July 2013 Zip File of Published Opinions Mandate: 22 July 2013 Case Title / Description
Horne v. Cumberland Cnty. Hosp. Sys., Inc., (12-1276) — headnotes Dismissal under Rule 12(b)(6) for failure to state a claim for relief for wrongful discharge in violation of public policy.
In re S.D.W., (12-1362) — headnotes Adoption; Consent required of unwed father; Due process
James v. Integon Nat'l Ins. Co., (12-1417) — headnotes UIM coverage
Johns v. Welker, (12-1154) — headnotes Concurrent custody and adoption proceedings; Subject matter jurisdiction
Malloy v. Preslar, (12-1523) — headnotes Interlocutory Appeal; Substantial Right; Hazard on Property
McKinnon v. CV Indus., Inc., (12-1165) — headnotes Attorney's fees under N.C. Gen. Stat. 75-16.1; Rule 11 sanctions.
State v. Hanif, (12-1108) — headnotes Plain error; admissibility of evidence; counterfeit controlled substance; Rule 404(b)
State v. Horskins, (12-1489) — headnotes First degree murder; Premeditation and deliberation; Sufficiency of the evidence; Character evidence; Gang membership
State v. Lowery, (12-1129) — headnotes Sufficiency of the evidence
State v. Nolen, (13-132) — headnotes Justice Reinvestment Act of 2011
State v. Pemberton, (12-1528) — headnotes Ineffective Assistance of Counsel; Admission of Guilt with Consent of Client; Need for Hearing Concerning Reasonableness of Trial Strategy; Remand for Imposition of Life with Parole Sentence
State v. Poole, (12-1150) — headnotes Ex Parte Domestic Violence Protective Order; N.C.G.S. § 50B-3.1; Procedural due process
State v. Sheppard, (12-1435) — headnotes Larceny from the person and felony larceny of goods worth more than $1,000 and classification as an habitual felon.
State v. Storm, (12-1498) — headnotes Jury Instructions; Lay Opinion Testimony; Closing Argument
Unpublished Opinions - Rule 30e - Zip File of Unpublished Opinions
Barrett v. SSC Charlotte Operating Co., LLC, (12-1271) Connor v. Jesco Constr. Corp., (12-1390) Hess v. Hermann-Hess, (12-1544) In re A.G., (13-27) In re A.N.M., (13-4) In re A.P., (12-1429) In re B.P., (13-264) In re E.K., (13-41) In re G.L.K., (13-92) In re K.M., (12-1479) In re M.I.B., (13-25) In re N.L., (12-1492) In re S.L.A., (13-257) In re T.T., (13-139) Mack v. Bd. oF Educ. of the Pub. Sch. of Robeson Cnty., (13-51) Parks v. Petsmart, Inc., (12-1511) Ritchie v. Ritchie, (13-247) State v. Bailey, (12-1516) State v. Brown, (12-1505) State v. Colson, (13-217) State v. Harris, (13-143) State v. Hawkins, (13-16) State v. Khan, (11-368-2) State v. Kittrell, (13-98) State v. Nobles, (13-60) State v. Ramirez, (13-213) State v. Randall, (12-1573) State v. Thompson, (13-90) State v. Williams, (12-1227) State v. Wilson, (12-1233) State v. Womack, (12-1474) State v. Yow, (12-1473) Tate v. Loftus, (12-1468) TD Bank, N.A. v. McGee, (12-1412) Yeager v. Yeager, (12-1379)
18 June 2013 Zip File of Published Opinions Mandate: 8 July 2013 Case Title / Description
Bynum v. Wilson Cnty., (12-779) — headnotes Appealability; Governmental Immunity; Water System as Proprietary Function
Callanan v. Walsh, (13-85) — headnotes Equitable Distribution and Superior Court Jurisdiction
Church v. Bemis Mfg. Co., (12-1433) — headnotes Workers Compensation- suitability of employment; workers Compensation-total disability
Fox v. PGML, LLC, (12-1257) — headnotes Premises liability; contributory negligence
Hackos v. Goodman, Allen & Filetti, PLLC, (12-1314) — headnotes Legal malpractice, Statute of Limitations, Statute of Repose
Halifax Reg'l Med. Ctr., Inc. v. Brown, (12-1480) — headnotes Joint venture; interference with contract
Hedgepeth v. Lexington State Bank, (12-1057) — headnotes Unfair and deceptive trade practices; Rule 41(b) of the Rules of Civil Procedure
In re Whittacre, (12-1175) — headnotes Appeal from Board of Elections decision; mootness
King v. N.C. Dep't of Commerce, (13-58) — headnotes Unemployment insurance benefits, good cause for separation from employer
Lumbermans Fin., LLC v. Poccia, (12-1410) — headnotes The Uniform Enforcement of Foreign Judgments Act
Smith v. Lake Bay E., LLC, (12-1541) — headnotes Interlocutory; Necessary parties
State v. Coleman, (12-1173) — headnotes Anonymous tip; Unreasonable mistaken belief of law; Insufficient Indicia of reliability.
State v. Dial, (12-1334) — headnotes Motion to Suppress; Protective Sweep
State v. Garcia, (12-972) — headnotes Admissibility of detective's statements made during interrogation
State v. Howard, (12-996) — headnotes Rule 404(B); Rule 403; Preservation
Trantham v. Michael L. Martin, Inc., (12-1160) — headnotes directed verdict, arguing different grounds on appeal, constructive fraud, negligent misrepresentation, unfair & deceptive trade practices, double recovery
Webb v. McJas, Inc., (12-906) — headnotes Entry of default; default judgment
Unpublished Opinions - Rule 30e - Zip File of Unpublished Opinions
Allen v. Allen, (12-956) Bodie v. Bodie, (12-1525) Brafford v. Brafford, (13-126) Delancey v. Delancey, (12-1512) Gordon v. Gordon, (12-1126) Gunter v. Gunter, (12-1222) In re A.A.J., (12-1555) In re C.J.B., (12-1572) In re K.P., (13-84) Jones v. Kidde Technologies, Inc., (12-1463) Livesay v. Carolina First Bank, (12-1177) Rogers v. Smithson, (12-1374) State v. Askew, (12-1187) State v. Banks, (12-1449) State v. Biggs, (13-71) State v. Broome, (13-31) State v. Cameron, (12-1256) State v. Cherry, (12-1074) State v. Coleman, (12-1075) State v. Connor, (12-1220) State v. Eaves, (12-1217) State v. Forte, (12-1562) State v. Haizlip, (12-1289) State v. Hilliard, (12-1196) State v. Hines, (13-50) State v. Jones, (12-1459) State v. Minter, (13-48) State v. Moore, (12-1440) State v. Nay, (12-817) State v. Parker, (12-754) State v. Randolph, (12-1310) State v. Royal, (12-1063) State v. Spake, (12-1451) State v. Velasquez-Cardenas, (12-1567) State v. Washington, (12-1559) State v. Williams, (12-1501) State v. Williams, (12-1337) Teague v. Forbes, (12-1421)
4 June 2013 Zip File of Published Opinions Mandate: 24 June 2013 Case Title / Description
Adams Creek Assocs. v. Davis, (12-1200) — headnotes Summary judgment; Torrens Act; adverse possession; motion to dismiss; contempt; sanctions
Blitz v. Agean, Inc., (12-1133) — headnotes Class certification
Booth v. State, (13-2) — headnotes Felony Firearms Act; Pardon
In re A.R., (12-1554) — headnotes Adjudication and disposition; Indian Child Welfare Act
In re D.A.H-C., (12-1537) — headnotes Termination of Parental Rights; Effect of Prior Appellate Opinion; Sufficiency of Evidentiary Support for Trial Court's Findings; Adequacy of Findings to Support a Determination of Neglect
In re E.H., (13-273) — headnotes Voluntary dismissal of a juvenile petition
In re Foreclosure of Young, (12-1224) — headnotes Trial court subject matter jurisdiction to hear foreclosure action in light of possible prior action pending; trial court subject matter jurisdiction to consider equitable defenses in strict foreclosure action
In re J.P., (13-35) — headnotes Waiver of Notice for Permanency Plan Hearing; Sufficiency of Visitation Plan; Sufficiency of Findings
In re L.G.I., (12-1369) — headnotes Adjudication and disposition; Visitation schedule
King v. Town of Chapel Hill, (12-1262) — headnotes Municipal authority to enact legislation; statutory construction; issuance of preliminary injunction
Smith v. City of Fayetteville, (11-1263-2) — headnotes Just and Equitable Tax Clause; Privilege License Tax; Electronic Sweepstakes
State v. Burrow, (11-773-2) — headnotes Sixth Amendment; Chemical Analysis Report; Notice
State v. Davis, (12-841) — headnotes Plea Agreement; jurisdiction
State v. Facyson, (12-1300) — headnotes Second-degree Murder; Motion to Dismiss; Aggravating Factor.
State v. Gentry, (12-1017) — headnotes Refusal to appoint substitute counsel; Denial of continuance motion; Allowance of request to proceed pro se
State v. Hernandez, (12-924) — headnotes Investigatory Detention; Appropriateness of Considering an Ineffective Assistance of Counsel Claim on Direct Appeal
State v. Hernandez, (12-1131) — headnotes Investigatory Detention; Appropriateness of Considering an Ineffective Assistance of Counsel Claim on Direct Appeal
State v. Marley, (12-770) — headnotes Driving While Impaired; Motion to Dismiss; Breathalyzer.
State v. Rogers, (12-1415) — headnotes First-degree Murder; First-degree Burglary; Premeditation and Deliberation; Lesser Included Offense
State v. Tucker, (12-1068) — headnotes Amendment of embezzlement indictment; Duty to account doctrine of territorial jurisdiction
Woodring v. Woodring, (12-679) — headnotes Family Law; Custody & Visitation; Temporary Orders Becoming Permanent by Operation of Time; Res Judicata; Custodial Parent having Exclusive Control Over Visitation
Unpublished Opinions - Rule 30e - Zip File of Unpublished Opinions
Anway v. Silver Creek Cmty. Prop. Owners Ass'n, Inc., (12-1460) Barbee v. Transit Mgmt. of Charlotte, Inc., (12-1001) Bernhardt v. N.C. Dep't of Pub. Safety/Highway Patrol, (12-1254) Couchon v. N.C. Dep't of Transp., (12-1226) Davis v. Chase Home Fin., LLC, (12-1246) Holmes v. Wake Cnty., (12-1332) Huff v. CBS Quality Cars, Inc., (12-1134) In re A.J.W., (12-1458) In re A.T.I., (13-80) In re C.H., (13-127) In re D.K., (13-117) In re D.L.B., (12-1387) In re D.L.C., (12-1330) In re E.C.M., (12-1408) In re E.M., (13-13) In re Foreclosure of Radisi, (13-74) In re H.S., (12-1430) In re J.M., (12-1392) In re J.R., (13-26) In re K.C., (12-1497) In re K.M., (12-1252) In re L.D.W., (12-1482) In re R.J.M., (13-40) In re T.A.D., (12-1368) Minar v. Murray, (12-1428) Simpson v. Avila, (12-1234) State v. Bajja, (12-1515) State v. Bass, (12-1237) State v. Benfield, (12-1383) State v. Black, (12-1510) State v. Brown, (12-708) State v. Caldwell, (12-1358) State v. Dash, (12-1508) State v. Daviau, (13-208) State v. Davis, (12-833) State v. Foreman, (12-1313) State v. Gorham, (12-1370) State v. Hairston, (12-1356) State v. Joyner, (12-1244) State v. Layton, (12-1197) State v. Markham, (12-1470) State v. Marley, (12-1216) State v. Martin, (12-1080) State v. McCray, (12-1309) State v. Rhodes, (12-1143) State v. Robinson, (12-1556) State v. Rojas, (12-1255) State v. Stanley, (12-1354) State v. Stokes, (12-810-2) State v. Stubbs, (12-1280) State v. Swann, (12-1171) State v. Williams, (12-991) State v. Womack, (12-1006) Toney v. Colonial Props. Trust, (12-1114) Walker v. N.C. Dep't of Corr., (12-1371) Wilhite v. Pike Elec., Inc., (13-19)
21 May 2013 Zip File of Published Opinions Mandate: 10 June 2013 Case Title / Description
Allred v. Exceptional Landscapes, Inc., (12-1278) — headnotes Workers' Compensation Act; Jurisdiction; Attorney's Fees; Piercing the Corporate Veil
Erie Ins. Exch. v. Builders Mut. Ins. Co., (12-1104) — headnotes Insurer's duty to defend; consideration of contract terms and legal briefs in hearing under Rule 12(c)
Hinkle v. Hinkle, (12-781) — headnotes Equitable Distribution; health and income; valuation of property
In re Bunch, (12-1367) — headnotes Termination of sex offender registration
In re I.K., (12-1053) — headnotes Cessation of reunification efforts; sufficient evidence; sufficient findings
Johnson v. Forsyth Cnty., (12-1339) — headnotes Whistle Blower Act; State Employee
Johnson v. Robertson, (12-959) — headnotes rules of Evidence; Standard of Review
N.C. Farm Bureau Mut. Ins. Co. v. Smith, (12-1442) — headnotes Insurance contract, Covenant not to execute
Redd v. Wilcohess, L.L.C., (12-639-2) — headnotes Jury Request; N.C. Gen. Stat. § 1-181.2
Reo Props. Corp. v. Smith, (12-860) — headnotes Lis Pendens
Russell v. N.C. Dep't of Env't & Natural Res., (12-801) — headnotes Torts Claims Act; Negligence; Expert Testimony; Measure of Damages; Mitigation of Damages
Smallwood v. Smallwood, (12-1229) — headnotes Sufficiency of evidence and findings to support determination regarding cohabitation
State v. Bean, (12-697-2) — headnotes unpreserved constitutional argument; plain error; right to silence; right to plead not guilty
State v. Bell, (12-1514) — headnotes Elements of armed robbery; Jury instructions; Victim impact testimony
State v. Cathcart, (12-1478) — headnotes Breath test procedures; Motion to Suppress
State v. Coleman, (12-946) — headnotes Plain error; jury instructions; trafficking
State v. Gardner, (12-969) — headnotes Motion for Postconviction DNA Testing
State v. Hill, (12-1502) — headnotes preservation of unanimity of jury issue; sufficiency of the evidence challenge for communicating threats and carrying a concealed weapon
State v. Ingram, (12-1327) — headnotes First-degree Murder; Premeditation and Deliberation; Lesser Included Offense
State v. King, (12-1275) — headnotes Motion to continue; Ineffective assistance of counsel; Crediability instruction
State v. Leach, (12-962) — headnotes Habeas Corpus; Procedural Due Process; Release on Parole
State v. Phillips, (12-852) — headnotes Jury instructions; sentencing court costs
State v. Primus, (12-1106) — headnotes Attempted felony larceny; jury instructions; injury to personal property
Ussery v. Branch Banking & Trust Co., (12-940) — headnotes Equitable Estoppel; Statute of Limitations Defense
Unpublished Opinions - Rule 30e - Zip File of Unpublished Opinions
Anderson v. Sodexo, (12-1575) Booe v. Booe, (12-1019) Consoli v. Global Supply & Logisitcs, Inc., (12-1283) Covington v. Serv. Corp. Int'l, (12-1149) HPT IHG Props. Trust. v. The Shaw Grp., Inc., (12-1223) In re Foster, (12-865) In re K.A.T.B., (12-1419) In re K.C., (12-1536) In re L.M.W., (12-1373) In re M.D.M.M., (12-1547) Krupinski v. Forrest, (12-1225) Leake v. N.C. Dep't of Corr., (12-1272) McNeil v. McNeil, (12-1396) Richardson v. PCS Phosphate Co., Inc., (12-824) Roberts v. Huckabee, (12-1352) Sasso v. Statesville Flying Serv., Inc., (12-935) Snider v. Snider, (12-1181) State v. Ellis, (12-861) State v. Floyd, (12-1123) State v. Hodges, (12-915) State v. Hunt, (12-1242) State v. Kinston, (12-1119) State v. Kirkman, (12-1288) State v. Locklear, (12-1348) State v. McCullers, (12-1214) State v. Rivas-Batres, (12-645) State v. Rorie, (12-1110) State v. Salgado, (12-1178) State v. Shaw, (12-1186) State v. Washington, (12-1294) State v. Weeks, (12-1388) State v. Wilson, (12-772) State v. Wright, (12-938) Watts v. Bell, (12-1553) Williams v. Hampton, (12-1273) Williams v. Humphreys, (12-814) Young v. Young, (12-1360)
7 May 2013 Zip File of Published Opinions Mandate: 28 May 2013 Case Title / Description
Bigelow v. Town of Chapel Hill, (12-1105) — headnotes Rule 12(c); Judgment on the Pleadings; N.C. constitutional claims
Diamond v. Charlotte-Mecklenburg Cnty. Bd. of Educ., (12-690) — headnotes Review of a school board decision; substandard evidence; reasonable force
Estate of Ray v. Forgy, (12-1071) — headnotes apparent agency; corporate negligence of hospitals; Rule 9(j) pleading requirements
Fulmore v. Howell, (12-1384) — headnotes Sudden emergency
Highland Paving Co., LLC v. First Bank, (12-1297) — headnotes Breach of contract; Quantum Meruit; Constructive Fraud; Unfair and Deceptive Trade Practices
Howard v. Cnty. of Durham, (12-1484) — headnotes Pre-audit certificate; Negligent misrepresentation; Mediated settlement conference
In re A.K.D., (12-1355) — headnotes Termination of Parental Rights; Willful Abandonment; Improper Stipulation
In re C.W.N., (12-485) — headnotes Juvenile delinquency; ineffective assistance of counsel
In re Suttles Surveying, P.A., (12-1350) — headnotes NC Board of Examiners of Engineers & Surveyors; Administrative Law; Due Process
In re V.C.R., (12-1127) — headnotes Search and seizure
Ludlum v. State, (12-1398) — headnotes Statute of Limitations and Military Retirement Benefits
Nunn v. N.C. Dep't of Pub. Safety, (12-1307) — headnotes Tort Claims Act; Prisoner safety; Necessary findings
Revolutionary Concepts, Inc. v. Clements Walker PLLC, (12-1167) — headnotes Assignability of malpractice claims; Rule 15 and 17 motions; Lack of knowledge of wrongdoing by members of an LLC
State Health Plan for Teachers & State Emps. v. Barnett, (12-999) — headnotes N..C. Gen. Stat. Section 135-45.15 (now N.C. Gen. Stat. Section 135-48.37); Attorney Liability
State v. Caudill, (12-1064) — headnotes Motion to suppress; N.C.G.S. § 15A-501 (2)
State v. Gerald, (12-1231) — headnotes Ineffective assistance of counsel
State v. Greenlee, (12-419) — headnotes Obtaining Property by False Pretense; Acting in Concert; Presence
State v. Heavner, (12-1005) — headnotes Motion to Dismiss; Rule of Lenity; Malicious Conduct by Prisoner; Motion for Appropriate Relief; Extraneous Evidence; Confrontation
State v. Macon, (12-812) — headnotes Effect of trial court's legal rulings in retrial following mistrial; sufficiency of evidence of refusal to submit to breath test
State v. Norman, (12-599) — headnotes Motion to dismiss; jury instructions; lesser included offense; attempt second degree rape
State v. Thomas, (12-979) — headnotes Entrapment
State v. Threadgill, (12-1293) — headnotes Prior record level; stipulation to felony classification of prior out-of-state convictions; ex post facto clause and prior convictions under N.C. Gen. Stat. § 15A-1340.11(7)
State v. Tindall, (12-1145) — headnotes Probation revocation
State v. Torres-Gonzalez, (12-831) — headnotes Conspiracy to traffic by possessing cocaine; trafficking by possession
State v. Vaughn, (12-1179) — headnotes Jury instruction on the aggressor element of self-defense; plain error
State v. Webb, (12-1268) — headnotes Substitution of Counsel; Probation Revocation Hearing; Prejudicial Error
State v. Williams, (12-1323) — headnotes Extraordinary mitigation
Unpublished Opinions - Rule 30e - Zip File of Unpublished Opinions
Arbona v. Williams, (12-1048) Bartlett v. Wayne Cnty. Bd. of Educ., (12-672) Bledsoe v. Bledsoe, (12-1043) Carolina Builders, Inc. v. Bible Way Cmty. Dev. Corp., (12-1416) Edwards v. Hackney, (12-1146) Embrace Us, Inc. v. The Guilford Ctr. For Behavioral Health, (12-970) FIA Card Servs., N.A. v. Ashworth, (12-958) In re A.C., (13-28) In re C.S.E., (12-1207) In re E.L.R., (12-1302) In re G.R., (12-1391) In re J.B., (12-1393) In re J.K.T., (12-1409) In re J.P., (12-1343) In re R.L.M., (12-1538) In re V.C.B., (12-1162) Mancuso v. City of Durham, (12-1331) Metts v. Parkinson, (12-1357) Nall Farm Rd., LLC v. Watson, (12-1420) Odugba v. Odugba, (12-733) Pinehurst Surgical Clinic, P.A. v. DiMichele-Manes, (12-830) Scheerer v. Fisher, (12-1002) State Bd. of Examiners of Plumbing, Heating, & Fire Sprinkler Contr'rs v. Kanupp, (12-1306) State v. Adams, (12-1345) State v. Allen, (12-1338) State v. Anderson, (12-1218) State v. Brown, (12-952) State v. Bynum, (12-1180) State v. Corbett, (12-1122) State v. Davis, (12-1120) State v. Dickens, (12-1353) State v. Fuentes, (12-1148) State v. Fuller, (12-1351) State v. Grimes, (12-1096) State v. Hairston, (12-985) State v. Harte, (12-1191) State v. Hernandez, (12-899) State v. Hopkins, (12-1296) State v. Johnson, (12-1026) State v. Kaalund, (12-1335) State v. Kanapaux, (12-739) State v. Kivett, (12-1324) State v. Leavitt, (12-1045) State v. Lincourt, (12-1249) State v. Martin, (12-1076) State v. Mayes, (12-1241) State v. McLaurin, (12-980) State v. McLean, (12-910) State v. Murchison, (12-1321) State v. Narron, (12-1077) State v. Price, (12-1317) State v. Sanders, (12-1192) State v. Shelton, (12-968) State v. Smith, (12-1477) State v. Sweatt, (12-1050) State v. Tarleton, (12-916) State v. Townsend, (12-1228) State v. Williamson, (12-1215) State v. Woods, (12-1189) Thrush v. Jones, (12-1147) Tuttle v. Tuttle, (12-1437) Tuttle v. Tuttle, (12-728)
16 April 2013 Zip File of Published Opinions Mandate: 6 May 2013 Case Title / Description
City of Wilson v. The Batten Family, L.L.C., (12-1103) — headnotes Condemnation; N.C.G.S. Sec. 136-108; appeal
Higginbotham v. D'Amico, (12-1099) — headnotes Standard of care; medical malpractice
In re E.K.H., (12-1253) — headnotes N.C. Gen Stat. 7B-2413, risk and needs assessments, predisposition report, prejudice
In re K.C., (12-1157) — headnotes Sexual battery; simple assault; juvenile adjudications in cases of undisciplined and delinquent juveniles; juvenile dispositions in cases of undisciplined and delinquent juveniles; ineffective assistance of counsel
IN THE MATTER OF: KEVIN MCCLAIN, (12-1258) — headnotes sexual offender registration; delegation of legislative authority; Adam Walsh Act; Jacob Wetterling Act; statutory interpretation
Katy v. Capriola, (12-625) — headnotes Expert Testimony; Contributory Negligence; Special Jury Instruction; Admissibility of Remarriage
Lake Toxaway Cmty. Ass'n, Inc. v. RYF Enters., Inc., (12-422) — headnotes Contract implied in fact; easement appurtenant; reasonable value of services
Little v. Little, (12-414-2) — headnotes Hearsay; judicial notice of criminal file; DVPO
Phelps Staffing, LLC v. C.T. Phelps, Inc., (12-886) — headnotes Validity of Noncompetition Agreement; Unfair and Deceptive Practices or Acts
Samost v. Duke Univ., (12-635) — headnotes Judgment on the Pleadings; Breach of Contract; Necessity for Compliance with Contractual Procedures
State v. Noble, (12-734) — headnotes Aiding and abetting a person under 21 years of age to possess or consume alcohol; Involuntary manslaughter.
State v. Quick, (12-1111) — headnotes Right to counsel; Miranda
State v. Ragland, (12-699) — headnotes Prosecutor's fallacy with regard to DNA evidence
State v. Rouson, (12-382) — headnotes Petition for writ of certiorari; plea agreement; motion to suppress; recitation of facts
State v. Steen, (12-1069) — headnotes Credibility of witnesses must be decided by the jury; invited error waives appellate review, including plain error
Town of Sandy Creek v. East Coast Contr'g, Inc., (12-561-2) — headnotes Governmental immunity; proprietary function
Unpublished Opinions - Rule 30e - Zip File of Unpublished Opinions
Adams v. Kalmar, (12-749) Congdon v. Congdon, (12-988) Grist v. Smith, (12-488) In re B.S.L.R., (12-1100) In re D.W.L., (12-1251) In re H.J.C., (12-1432) In re H.S.G., (12-1012) In re J.C., (12-1182) In re K.C.P., (12-1230) In re N.A.R., (12-1240) In re R.D., (12-1400) Jackson v. Tim Maguire, Inc., (12-1098) Moore v. Moore, (12-1058) Moore v. Smith, (12-1118) Quality Built Homes, Inc. v. N.C. Dep't of Env't & Natural Res., (12-1020) State v. Baber, (12-1121) State v. Bellamy, (12-890) State v. Gregory, (12-793) State v. Haith, (12-933) State v. Lewis, (12-1056) State v. Lindsay, (12-1319) State v. McLeod, (12-939) State v. Miller, (12-818) Opinion not available State v. Thompson, (12-1274) State v. Wicks, (12-912)
2 April 2013 Zip File of Published Opinions Mandate: 22 April 2013 Case Title / Description
Anglin v. Dunbar Armored, Inc., (12-1176) — headnotes N.C. Gen. Stat. § 97-10.2(j); Choice of Law
Beason v. N.C. Dep't of Sec'y of State, (12-837) — headnotes The Lobbying Laws; Violations based on common law; Lobbyist principal.
Beason v. N.C. Dep't of Sec'y of State, (12-874) — headnotes Declaratory Ruling; Mootness.
Beason v. N.C. Dep't of Sec'y of State, (12-838) — headnotes The Lobbying Laws; Authority of Administrative Agency; Definition of a Lobbyist.
Hausle v Hausle, (12-967) — headnotes Interlocutory appeal; attorney fees; child custody
In re L.C.R., (12-1195) — headnotes Termination of Parental Rights; Failure to Make Reasonable Progress; Custody
Novak v. Daigle, Inc., (12-1206) — headnotes Rule 60(b) hearing; Handwritten order
Powe v. Centerpoint Human Servs., (12-849) — headnotes Workers compensation; Rule 37 of the N.C. Rules of Civil Procedure; Plaintiff's right to compensation--finding of disability; Vocational rehabilitation; Standard of review of Industrial Commission
Reeder v. Carter, (12-1084) — headnotes Separation Agreements; Specific Performance; Enforceability of Contractual Specific Performance Clauses; Ability to Perform; Adequacy of Legal Remedy
State v. Arrington, (12-1333) — headnotes Satellite Based Monitoring; Offense against a minor; Recidivist
State v. Barnes, (12-278) — headnotes Confrontation Clause; Right to Discovery; Jury Instructions
State v. Hadden, (12-922) — headnotes Findings regarding statutory grounds for qualification for SBM
State v. Hazel, (12-1102) — headnotes Trafficking; constructive possession; combined weights
State v. Heien, (11-52-2) — headnotes Motion to suppress; search and seizure; consent
State v. Hunnicutt, (12-1018) — headnotes Probation Revocation; Collateral Attack
State v. Phifer, (12-1124) — headnotes Reasonable suspicion for search and nervousness
State v. Ramseur, (12-62) — headnotes Motion for Appropriate Relief; self-defense; defense of others
State v. Renkosiak, (12-975) — headnotes Embezzlemenht
State v. Richardson, (11-1581-2) — headnotes Questions and Comments About a Defendant's Right to Silence; Plain Error Review
State v. Sessoms, (12-1232) — headnotes Plain error; Character evidence; Opinion testimony
State v. Ward, (12-1125) — headnotes Confrontation Clause
State v. Williams, (12-1034) — headnotes Stalking; Ex Post Facto; Plain error; Violation of a protective order
Williams v. Bank of Am., (12-965) — headnotes Commission's discretion under Rule 801 to waive compliance with Rule 701
Unpublished Opinions - Rule 30e - Zip File of Unpublished Opinions
Arrow v. Pine Lake Preparatory, Inc., (12-1004) Avent v. PLT Constr., (12-1107) Bookman v. Britthaven, Inc., (12-663) Carolina Coast & Lakes, Inc. v. The Shores at Lands End Homeowners, (12-998) Crowell v. Davis, (12-859) Furr v. Porters Neck Country Club, Inc., (12-1095) Haynesworth v. Am. Express Travel, (12-472) In re A.C., (12-1342) In re D.A.D., (12-1091) In re J.M., (12-1340) In re P.L.R., (12-1341) In re T.R., (12-1291) In re Z.K.M., (12-1161) R.D. Furr Constr., Inc. v. Porters Neck Country Club, Inc., (12-1092) Rainey v. Goodyear Tire & Rubber Co., (12-588) State v. Burroughs, (12-955) State v. Burroughs, (12-1015) State v. Clubb, (12-1185) State v. Finney, (12-997) State v. Gaffney, (12-707) State v. Jenkins, (12-1085) State v. Kirkpatrick, (12-1198) State v. Mayhew, (12-866) State v. McGhee, (12-782) State v. McLean, (12-502) State v. McMillian, (12-1170) State v. Medley, (12-900) State v. Milanese, (12-1061) State v. Moll, (12-755) State v. Navarrete-Garcia, (12-1039) State v. Scriven, (12-1188) State v. Shuler, (12-986) State v. Simpson, (12-1024) State v. Stevens, (12-843) State v. Taylor, (12-945) State v. Wingo, (12-1156) Williams v. CW Peters, LLC, (12-1079)
19 March 2013 Zip File of Published Opinions Mandate: 8 April 2013 Case Title / Description
Bissette v. Harrod, (12-921) — headnotes Breach of Express Trust Requisites for Express Trust Equitable Trusts
Gray v. United Parcel Serv., Inc., (12-1029) — headnotes Workers' Compensation Act; expert testimony
Hardison v. KIA Motors Am., Inc., (12-981) — headnotes New Motor Vehicles Warranty Act; North Carolina Lemon Law; Attorney's Fees; Treble Damages
Hillsboro Partners, LLC v. City of Fayetteville, (12-987) — headnotes Collateral estoppel; Governmental talking; Just compensation
In re Appeal of Blue Ridge Hous. of Bakersville, LLC, (12-941) — headnotes Ad valorem property tax exemption; N.C. Gen. Stat. § 105-278.6(a)(8); low-income housing tax credits; housing authorities; ownership interest
Joines v. Moffitt, (12-1027) — headnotes Admissibility of accident report; Limiting voir dire; Opinion testimony as to right of way
O'Neal v. O'Neal, (12-715) — headnotes Rule 11 sanctions, amount of attorney's fees
Stark v Ford Motor Co., (09-286-2) — headnotes Motions for JNOV and New Trial; Expert Witness Fees; Liability of Guardian ad Litem for Costs
State v. Combs, (12-1008) — headnotes Rape of a child; First degree sexual offense; Sufficiency of the evidence; Jury instructions
State v. Davis, (12-1054) — headnotes Flight; action not part of normal behavior; prior record level substantially similar offense
State v. Galloway, (12-1049) — headnotes Discharging a firearm into an occupied vehicle in operation; Sufficiency of the indictment
State v. Hinton, (12-796) — headnotes Gang-related testimony; plain error; jury request to review trial testimony; failure to exercise discretion; prejudicial error
State v. James, (12-1089) — headnotes Armed robbery; Acting in concertg
State v. Rollins, (12-552) — headnotes Confrontation Clause; Hearsay; Prior Testimony; Voluntariness
State v. Seelig, (12-442) — headnotes Physical presence requirement of Confrontation Clause
Walters v. Cooper, (12-1221) — headnotes Prayer for judgment continued; sex offender registration
Wells Fargo Bank, N.A. v. Arlington Hills of Mint Hill, LLC, (12-1060) — headnotes Foreclosure; off-set defense
Wind v The City of Gastonia, (12-421) — headnotes whether a city employee has the right to inspect confidential materials in his own employee personnel file pursuant to N.C.G.S. 160A-168(c)(1) and N.C.G.S. 160A-168(c1)(4)
Unpublished Opinions - Rule 30e - Zip File of Unpublished Opinions
Antelo v. Wal-Mart Assocs., Inc., (12-846) Boyd v. N.C. Dep't of Health & Human Servs., (12-823) Brodie v. Excel Staffing Servs., (12-885) Carden v. Owle Constr., LLC, (12-493) Foreclosure of Perry, (12-944) Godon Constr., Inc. v. Primo Enters., LLC, (12-335) In re A.J.W., (12-1138) In re Foreclosure of Dong, (12-942) In re J.M., (12-1014) In re J.W., (12-880) In re K.A.U., (12-1046) In re S.S., (12-1011) Indep. Technologies, Inc. v. Martin, (12-872) Lawing v. Lawing, (12-982) Lowder v. Payne, (12-512) McCallister v. Lee, (12-1168) Menius v. CEI Transp., Inc., (12-929) Metts v. Metts, (12-427) N.C. State Bar v. Burford, (12-909) State v. Avery, (12-695) State v. Bennett, (12-870) State v. Burris, (12-892) State v. Claros, (12-994) State v. Cook, (12-519) State v. Fennell, (12-993) State v. Haire, (12-1086) State v. Harris, (12-864) State v. Jones, (12-934) State v. Kee, (12-784) State v. Klinger, (12-798) State v. Long, (12-1263) State v. Moore, (12-1025) State v. Pollock, (12-971) State v. Rice, (12-735) State v. Taylor, (12-529) State v. Thompson, (12-1193) State v. Zinkand, (12-756) Williard v. Williard, (12-931)
5 March 2013 Zip File of Published Opinions Mandate: 25 March 2013 Case Title / Description
Carle v. Wyrick, Robbins, Yates & Ponton, LLP, (12-1093) — headnotes Legal malpractice; Statute of repose
Charles Schwab & Co., Inc. v. McEntee, (12-897) — headnotes Intervention as of right pursuant to Rule 24(a)(2); permissive intervention pursuant to Rule 24(b); estate beneficiary; estate personal representative?s powers and duties.
Fairway Outdoor Adver. v. Town of Cary, (12-518) — headnotes Town ordinances
Falk v Fannie Mae, (12-764) — headnotes Foreclosure; life of lien statute
Hankins v. Bartlett, (12-1051) — headnotes Reciprocal Wills; Will Contracts; Statute of Frauds
Helfrich v. Coca-Cola Bottling Co. Consol., (12-106) — headnotes Disability Two Separate Injuries Compensation Rate
In re Appeal of Parkdale Mills, (12-1078) — headnotes Real Property Tax; Real Property Valuation
Inland Harbor Homeowners Ass'n, Inc. v St. Josephs Marina, LLC, (11-715-3) — headnotes Judicial Reformation; Mutual Mistake
Redd v Wilcohess, L.L.C., et al, (12-639) — headnotes Slip and Fall; Last Clear Chance; Jury instructions; Jury Request to View Evidence
State v. Braswell, (12-876) — headnotes Obtaining Property by False Pretenses; Sufficiency of the Evidence
State v. Cook, (12-902) — headnotes Resentencing
State v. Dew, (12-642) — headnotes Child Sexual Abuse; Admissibility of Testimony Allegedly Vouching for the Credibility of the Prosecuting Witnesses; Admissibility of Expert Testimony
State v. Hatfield, (12-961) — headnotes Jury request to review trial testimony; failure of trial court to exercise discretion; prejudicial error
State v. Mills, (12-855) — headnotes Batson hearing; peremptory challenges; Rule 803; Hearsay
State v. Morgan, (12-889) — headnotes Motion to Suppress ? Necessity of Written Order; Indictment for Statutory Rape ? N.C. Gen. Stat. §§ 14-27.7A(a) and 15-144.1.
State v. Warren, (12-811) — headnotes Admissibility of evidence; personal knowledge; preservation of argument for appeal; variance from indictment; motion to dismiss; isufficiency of the evidence
Thigpen v. Cooper, (12-582) — headnotes Persons under 42 USC 1983
White v. Nw. Prop. Grp.-Hendersonville #1, LLC, (12-1037) — headnotes Change of grade; Loss of access to right-of-way
Yingling v. Bank of Am., (12-1031) — headnotes Workers' compensation; Written notice; Reasonable Excuse; Actual knowledge
Unpublished Opinions - Rule 30e - Zip File of Unpublished Opinions
Baines v. Baines, (12-829) Bell v. Goodyear Tire & Rubber Co., (12-1009) Criswell v. Wheatley, (12-786) D.P. Solutions, Inc. v. Xplore-Tech Servs. Private Ltd., (12-925) Hickory Mountain Farms, LLC v. Van Vooren Holdings, Inc., (12-1000) Highsmith v. Clark, (12-1041) In re A.N.R., (12-1042) In re H.C.S., (12-879) In re H.N.H., (12-857) In re K.L., (12-1023) In re K.N.E.S., (12-1003) In re L.N.J., (12-920) In re S.J., (12-877) In re T.F., (12-1082) In re W.D.W., (12-894) McKee v. Smith, (12-1194) Moore v. Bell Senior Living, (12-440) Pippens v. May, (12-821) Pohlman v. Magen's Bay Home Owners Assoc., Inc., (12-327) State v. Alston, (12-815) State v. Baltazar, (12-644) State v. Bass, (12-828) State v. Boykin, (12-816) State v. Bradsher, (12-1010) State v. Farmer, (12-1067) State v. Gross, (12-951) State v. Hogan, (12-835) State v. Johnson, (12-1184) State v. McRae, (12-1088) State v. Richardson, (12-731) State v. Thomas, (12-891) State v. Whitaker, (12-527) Wofford v. Cook, (12-966)
19 February 2013 Zip File of Published Opinions Mandate: 11 March 2013 Case Title / Description
In re A.P.W., (12-807) — headnotes Necessity of findings in order ceasing reunification efforts; N.C. Gen. Stat. § 7B-507(b).
In re B.S.O., (12-878) — headnotes Termination of parental rights; re-opening evidence
In re D.A.C., (12-568) — headnotes Denial of Suppression Motion Is Juvenile Suspect in Custody
In re T.J.C., (12-927) — headnotes Termination of parental rights; Neglect; Adequate findings of fact
In re T.R.T., (12-905) — headnotes Child neglect; visitation; electronic visitation
Manning v. Anagnost, (12-1030) — headnotes Medical Malpractice, Bolstering Credibility
Richmond Cnty. Bd. of Educ. v. Cowell, (12-1022) — headnotes Whether State has waived defense of sovereign immunity as to direct constitutional claim brought by county school board against State alleging violation of N.C. Const. art. IX, sec. 7.
State v. Chisholm, (12-901) — headnotes Counterfeit Controlled Substance; Constructive Possession; Lay Opinion Testimony
State v. Dorman, (12-97) — headnotes Murder; Due Process; Criminal Discovery; Destruction of Evidence
State v. Thomas, (12-667) — headnotes Satellite-based Monitoring; Additional Findings; Offense against a Minor
State v. Williams, (12-947) — headnotes Burden of Proof at Suppression Hearing; Probable Cause
Timber Integrated Invs., LLC v. Welch, (12-767) — headnotes Summary Judgment; piercing the corporate veil
Unpublished Opinions - Rule 30e - Zip File of Unpublished Opinions
Fairbrother v. Mann, (12-780) Gerringer v. Pfaff, (12-785) In re B.C.V., (12-914) In re B.S., (12-1164) In re F.M., (12-1032) In re G.P., (12-1070) In re J.M.D.R., (12-1235) In re J.N.S., (12-1021) In re L.H.T., (12-1073) In re S.A.C., (12-989) In re S.S., (12-1112) Jordans Constr., Inc. v. Forest Springs, LLC, (12-904) Judson v. Weiss, (12-403) Mahbuba v. Washington, (12-949) State v. Franklin, (12-851) State v. Horton, (12-366) State v. Howard, (12-687) State v. Lambert, (11-1574-2) State v. Lucas, (12-710) State v. Martin, (12-795) State v. Parker, (12-836) State v. Sheppard, (12-737) State v. Taft, (12-646) State v. Williams, (12-753) Stepp v. Awakening Heart, PA, (12-581)
5 February 2013 Zip File of Published Opinions Mandate: 25 February 2013 Case Title / Description
Carpenter v. Carpenter, (12-820) — headnotes Custody order; Sufficient findings of fact
Green v. Kearny, (12-678) — headnotes Liability for Court Costs Incurred After Entry of Partial Summary Judgment
Handy Sanitary Dist. v. Badin Shores Resort Owners Ass'n, Inc., (12-873) — headnotes Conditions precedent; Consent order
Housecalls Home Health Care, Inc. v. State, (12-839) — headnotes Res judicata
In re A.N.C., (12-482) — headnotes Roadside Questioning Is Suspect in Custody Hit-and-Run Statute
In re D.C., (12-893) — headnotes Termination of parental rights; N.C. Gen. Stat. § 7B-1111(a)(2)
In re E.J., (12-673) — headnotes Child abuse and neglect; UCCJEA; subject matter jurisdiction
King v. Bryant, (12-918) — headnotes Arbitration Agreement; Indefiniteness; Unconscionability; Fiduciary Relationship
Ludlam v. Miller, (12-637) — headnotes Child support guidelines; imputed income; unemployed parent; health insurance
McCrann v. Pinehurst, LLC, (12-680) — headnotes Restrictive Covenants; Standing; Unfair or Deceptive Acts or Practices
McCrary v. King Bio, Inc., (12-405) — headnotes Origin of Pain Need for Expert Evidence Showing Sufficient
Pender v. Lambert, (12-714) — headnotes Workers' Compensation; employee liability
Ramey Kemp & Assocs., Inc. v Richmond Hills Residential Partners, LLC, (12-121) — headnotes Enforcement of Lien Timeliness of Claim of Lien Date Work Last Performed
State v. Banks, (12-531) — headnotes Motion for Appropriate Relief; Double Jeopardy; Legislative Intent
State v. Boone, (12-675) — headnotes Probation revocation; Sufficiency of the evidence
State v. Crawford, (12-565) — headnotes Calculation of prior record level; ineffective assistance of counsel; sufficiency of factual basis to support a guilty plea.
State v. Gray, (12-153) — headnotes Conflict of Interest; Refusal to Waive Conflict; Lack of Inquiry
State v. Johnson, (12-827) — headnotes Strip search; Warrantless search
State v. Lovette, (12-794) — headnotes Jury voir dire; mandatory sentences for juveniles
State v. Smith, (12-809) — headnotes Resisting a public officer; Unlawful arrest; Motion for mistrial
State v. Stokes, (12-810) — headnotes second degree kidnapping; removal of few feet
State v. Wilkins, (12-869) — headnotes Possession of Firearm by Felon; Indictment; Habitual Felon
State v. Wilson, (12-954) — headnotes Motion to Suppress-Impermissibly suggestive identification procedure, Eyewitness Identification Reform Act
Taft v. Brinleys Grading Servs., Inc., (12-790) — headnotes Special employment doctrine
Williams v. Lynch, (12-682) — headnotes Rule 41 and relation back of claims in second complaint
Unpublished Opinions - Rule 30e - Zip File of Unpublished Opinions
Beck v. Beck, (12-685) Burton v. ArvinMeritor, Inc., (12-320) Estate of Brittany Bridges v. NC Farm Bureau Mut. Ins. Co., Inc., (12-567) Estate of Matthew Bridges v. N.C. Farm Bureau Mut. Ins. Co., Inc., (12-566) Farley v. Farley, (12-377) Fragale v. Hutchinson, (12-953) Hairston v. Collins, (12-1016) Haughton v. HSBC Banks USA, (12-420) Holloway v. CV Indus., Inc., (12-868) In re F.L.C., (12-718) In re J.E., (12-978) In re J.Z.B., (12-727) In re K.M.N., (12-762) In re S.D., (12-1052) In re S.S., (12-896) Kelly v. Realty World Cape Fear, (12-822) Kopf v. Smartflow Technologies, Inc., (12-612) Lassiter v. Town of Selma, (12-845) Lawyers Paralegal Training Programs, LLC v. Guilford Coll., (12-805) Nationwide Prop. & Cas. Ins. Co. v. Brinley's Grading Serv., Inc., (12-276) Otto v. Certo, (12-1028) Sadler v. Scott Lowery Law Office, P.C., (12-825) State v. Brown, (12-848) State v. Caviness, (12-643) State v. Dunlap, (12-657) State v. Jones, (12-385) State v. Lindsey, (11-612-2) State v. McNeely, (12-579) State v. Memije, (12-263) State v. Moore, (12-365) State v. Moretti, (12-468) State v. Muhammad, (12-963) State v. Parks, (12-608) State v. Rankins, (12-620) State v. Rendleman, (12-463) State v. Snipes, (12-542) State v. Ward, (12-295) State v. Willis, (12-689) State v. Wilson, (12-819) Wright v. Wal-Mart, Inc. #1127, (12-592)
15 January 2013 Zip File of Published Opinions Mandate: 4 February 2013 Case Title / Description
Crossman v. Life Care Ctrs. of Am., Inc., (12-702) — headnotes Pre-dispute arbitration agreements; Impossibility of performance of contract; Severability clause in arbitration agreement; Selection of arbitrators
Docrx, Inc. v. EMI Servs. of NC, LLC, (12-783) — headnotes Foreign judgment; Rule 60(b)
Finney v. Finney, (12-292) — headnotes Burdens of proof for classification of property in equitable distribution case
Greene v. City of Greenville, (12-908) — headnotes Gross Negligence; Police Pursuits
In re A.Y., (12-80) — headnotes Role of parents' GAL in abuse, neglect and dependency cases
In re Dunn, (12-656) — headnotes Termination of sex offender registration.
In re foreclosure of Gray, (12-854) — headnotes Foreclosure by Power of Sale, Statutory Violation
McAdoo v. Univ. of N.C. at Chapel Hill, (12-256) — headnotes Student-Athletes; Intercollegiate Athletics; NCAA; Justiciability; Standing; Mootness
Overton v. Evans Logging, Inc., (12-761) — headnotes Motion to Dismiss; Negligence; Premises Liability
Rutherford Plantation, LLC v. The Challenge Golf Grp. Of the Carolinas, LLC, (12-666) — headnotes Rule 59, purchase money deed of trust
Shaw v. Goodyear Tire & Rubber Co., (12-338) — headnotes Workers' Compensation; Jurisdiction
Spivey v. Wright's Roofing, (12-270) — headnotes Workers' Compensation; Validity of Request to Set Aside Form 60 Filing for Mistake or Other Reasons
State of N.C., ex rel. Utilities Comm'n v. Carolina Water Serv., Inc. of N.C., (12-475) — headnotes Assignment of gain on sale and N.C. Utilities Commission's policy on that; Utilities law; Errors of law; Substantive due process for Equal Protection; Taking without just compensation
State v. Broom, (12-209) — headnotes First-degree murder; attempted first-degree murder; preselection jury instruction; jury instruction on lesser-included offense
State v. Claxton, (12-556) — headnotes Criminal sentencing; prior out-of-state convictions
State v. Gardner, (12-564) — headnotes Improper notice of appeal and certiorari; Stipulation of prior record level; Consolidation of judgments and calculation of prior record level; Conflicting line of cases
State v. Garrison, (12-589) — headnotes Habitual misdemeanor; assault; jury instructions; plain error
State v. Hoskins, (12-799) — headnotes Habitual Felon; Evidence
State v. Jones, (12-992) — headnotes Probation revocation under the Justice Reinvestment Act of 2011
State v. Lanford, (12-623) — headnotes Malicious castration; sufficiency of the evidence; multiple counts of assault; closed circuit television
State v. McKenzie, (12-436) — headnotes DWI; License Revocation; Commercial Driver?s License; Double Jeopardy, Due Process
State v. Sanders, (12-676) — headnotes Inclusion of out-of-state convictions in Defendant's prior record level; Substantial similarity
State v. Wilkes, (12-387) — headnotes Assault with a Deadly Weapon with Intent to Kill Inflicting Serious Injury; Double Jeopardy; Sentencing; Mitigating Factors
State v. Wilson, (12-641) — headnotes Timeliness of notice of appeal given after oral rendition of order but prior to entry of written order; dismissal of criminal charge for constitutional violation.
WakeMed v. N.C. Dep't of Health & Human Servs., (12-364) — headnotes Certificate of Need; Criterion 13(a)
Unpublished Opinions - Rule 30e - Zip File of Unpublished Opinions
Acker v. Whole Foods Mkt., (12-757) Andrews v. Land, (12-847) Arrowood v. Robinson, (12-466) Dixon v. Gifford, (12-520) Edwards v. Edwards, (12-882) Gould v. Gould, (12-662) Hoyle v. K.B. Toys Retail, Inc., (12-473) In re H.A.B., (12-788) In re I.G.R., (12-704) In re J.D.O., (12-884) In re J.R.S., (12-777) In re M.J.J., (12-653) In re N.E., (12-78) In re R.A.A., (12-741) In re Z.M.L., (12-406) Jemm, LLC v. Crawford, (12-683) Johnson v. Bank of Am., N.A., (12-562) Little v. Little, (12-414) Live, Inc. v. Dominos Pizza, LLC, (12-930) Martin v. OSI Rest. Partners, LLC, (12-887) Murphy v Goodyear Tire & Rubber Co., (12-871) Musante v. Bost Constr. Co., (12-647) Nordstrom v. Shaw, (12-917) Robinson v. Lassiter, (12-957) State v. Anderson, (12-928) State v. Aviles, (12-698) State v. Ball, (12-610) State v. Belcher, (12-674) State v. Branch, (12-883) State v. Byrd, (12-555) State v. Carle, (12-389) State v. Coffey, (12-842) State v. Fraley, (12-832) State v. Garcia, (12-973) State v. Gillis, (12-339) State v. Goode, (12-736) State v. Herron, (12-300) State v. Hiner, (12-881) State v. Hudson, (12-294) State v. Hunt, (12-481) State v. Jackson, (12-490) State v. Jacobs, (12-696) State v. Lemons, (12-913) State v. Leonard, (12-570) State v. Logan, (12-740) State v. Maberson, (12-227) State v. McQueen, (12-467) State v. Mullett, (12-862) State v. Navey, (12-432) State v. Parker, (12-380) State v. Paul, (12-937) State v. Santibanez, (12-177) State v. Silver, (12-479) State v. Simmons, (12-834) State v. Stevens, (12-132) State v. Taylor, (12-652) State v. Wade, (12-587) State v. Wheeler, (12-711) State v. Wilson, (12-655) State v. Wood, (12-355) Ward v. Ward, (12-844)